@@ -48,6 +48,11 @@ except:
      float64 = float32 = float16 = complex64 = complex128 = bool_ = FakeObject
 
 
+NUMERIC_NUMPY_TYPES = (int64, int32, int16, int8, uint64, uint32, uint16,
+                       uint8, float64, float32, float16, complex64, complex128,
+                       bool_)
+
+
 def get_numpy_dtype(obj):
     """Return NumPy data type associated to obj
     Return None if NumPy is not available
@@ -346,10 +351,6 @@ def value_to_display(value, minmax=False, level=0):
     np_printoptions = FakeObject
 
     try:
-        numeric_numpy_types = (int64, int32, int16, int8,
-                               uint64, uint32, uint16, uint8,
-                               float64, float32, float16,
-                               complex128, complex64, bool_)
         if ndarray is not FakeObject:
             # Save printoptions
             np_printoptions = get_printoptions()
@@ -370,11 +371,11 @@ def value_to_display(value, minmax=False, level=0):
                     try:
                         display = 'Min: %r\nMax: %r' % (value.min(), value.max())
                     except (TypeError, ValueError):
-                        if value.dtype.type in numeric_numpy_types:
+                        if value.dtype.type in NUMERIC_NUMPY_TYPES:
                             display = str(value)
                         else:
                             display = default_display(value)
-                elif value.dtype.type in numeric_numpy_types:
+                elif value.dtype.type in NUMERIC_NUMPY_TYPES:
                     display = str(value)
                 else:
                     display = default_display(value)
@@ -447,7 +448,7 @@ def value_to_display(value, minmax=False, level=0):
             display = str(value)
         elif (isinstance(value, NUMERIC_TYPES) or
               isinstance(value, bool) or
-              isinstance(value, numeric_numpy_types)):
+              isinstance(value, NUMERIC_NUMPY_TYPES)):
             display = repr(value)
         else:
             if level == 0:
